diff -uNr Chromium-orig/configure Chromium-0.9/configure
--- Chromium-orig/configure	Fri May 11 07:17:12 2001
+++ Chromium-0.9/configure	Tue Oct  1 17:12:21 2002
@@ -11,6 +11,9 @@
 ENABLE_SMPEG="yes"
 ENABLE_VORBIS="no"
 ENABLE_SETUP="yes"
+ENABLE_OPENAL="yes"
+OPENAL_FLAGS="-DOLD_OPENAL -DAUDIO_OPENAL"
+ENABLE_SDLMIXER="no"
 
 ## Where do we look for stuff?
 ###################################
@@ -64,6 +67,19 @@
 	ENABLE_SMPEG="no"
 fi
 
+## Check SDL_MIXER installation
+######################################################################
+if [ $ENABLE_SDLMIXER = "yes" ]; then
+	print_message ""
+	print_message "Verify SDL_mixer install:"
+	print_message "------------------"
+	ld -lSDL_mixer && print_message "ok." || (print_message "Error: ld -lSDL_mixer returned false."; exit 1;)
+	SDL_LIBS="\`\$(SDL_CONFIG) --libs\` -lSDL_mixer"
+	SDLMIXER_FLAGS="-DAUDIO_SDLMIXER"
+	ENABLE_OPENAL="no"
+	OPENAL_FLAGS=""
+fi
+
 ## Check smpeg installation
 ######################################################################
 if [ $ENABLE_SMPEG = "yes" ]; then
@@ -158,26 +174,33 @@
 ## set up other config.mak variables
 ######################################################################
 GL_LIBS="-lglpng -lGL -lGLU -lm"
-AL_LIBS="-L../support/openal/lib -lopenal -ldl" 
-AL_CFLAGS="-I../support/openal/linux/include -I../support/openal/include"
+if [ $ENABLE_OPENAL = "yes" ]; then
+	AL_LIBS="-L../support/openal/lib -lopenal -ldl" 
+	AL_CFLAGS="-I../support/openal/linux/include -I../support/openal/include"
+else
+	AL_LIBS=""
+	AL_CFLAGS=""
+fi;
 
 ## write out config.mak
 ######################################################################
 echo "OPENAL_CONFIG_OPTS = $OPENAL_CONFIG_OPTS" > config.mak
-echo ""                               >> config.mak
-echo "SDL_CONFIG   = $SDL_CONFIG"     >> config.mak
-echo "SMPEG_CONFIG = $SMPEG_CONFIG"   >> config.mak
-echo ""                               >> config.mak
-echo "AL_CFLAGS    = $AL_CFLAGS"      >> config.mak
-echo "SDL_CFLAGS   = $SDL_CFLAGS"     >> config.mak
-echo "SMPEG_CFLAGS = $SMPEG_CFLAGS"   >> config.mak
-echo "PKG_CFLAGS   = $PKG_CFLAGS"     >> config.mak
-echo ""                               >> config.mak
-echo "GL_LIBS      = $GL_LIBS"        >> config.mak
-echo "AL_LIBS      = $AL_LIBS"        >> config.mak
-echo "SDL_LIBS     = $SDL_LIBS"       >> config.mak
-echo "SMPEG_LIBS   = $SMPEG_LIBS"     >> config.mak
-echo "VORBIS_LIBS  = $VORBIS_LIBS"    >> config.mak
+echo ""                                  >> config.mak
+echo "SDL_CONFIG      = $SDL_CONFIG"     >> config.mak
+echo "SMPEG_CONFIG    = $SMPEG_CONFIG"   >> config.mak
+echo ""                                  >> config.mak
+echo "AL_CFLAGS       = $AL_CFLAGS"      >> config.mak
+echo "SDL_CFLAGS      = $SDL_CFLAGS"     >> config.mak
+echo "SMPEG_CFLAGS    = $SMPEG_CFLAGS"   >> config.mak
+echo "PKG_CFLAGS      = $PKG_CFLAGS"     >> config.mak
+echo ""                                  >> config.mak
+echo "GL_LIBS         = $GL_LIBS"        >> config.mak
+echo "AL_LIBS         = $AL_LIBS"        >> config.mak
+echo "SDL_LIBS        = $SDL_LIBS"       >> config.mak
+echo "SMPEG_LIBS      = $SMPEG_LIBS"     >> config.mak
+echo "VORBIS_LIBS     = $VORBIS_LIBS"    >> config.mak
+echo "SDLMIXER_FLAGS  = $SDLMIXER_FLAGS" >> config.mak
+echo "OPENAL_FLAGS    = $OPENAL_FLAGS"   >> config.mak
 
 
 ## done!
@@ -186,9 +209,17 @@
 print_separator
 print_message "wrote ./config.mak"
 if [ $ENABLE_SETUP = "yes" ]; then
-	cp -f ./scripts/Makefile.all ./Makefile
+	if [ $ENABLE_SDLMIXER = "yes" ]; then
+		cp -f ./scripts/Makefile.all.sdlmixer ./Makefile
+	else
+		cp -f ./scripts/Makefile.all ./Makefile
+	fi;
 else
-	cp -f ./scripts/Makefile.no-setup ./Makefile
+	if [ $ENABLE_SDLMIXER = "yes" ]; then
+		cp -f ./scripts/Makefile.no-setup.sdlmixer ./Makefile
+	else
+		cp -f ./scripts/Makefile.no-setup ./Makefile
+	fi;
 fi
 print_message "wrote ./Makefile"
 print_message ""
diff -uNr Chromium-orig/scripts/Makefile.all.sdlmixer Chromium-0.9/scripts/Makefile.all.sdlmixer
--- Chromium-orig/scripts/Makefile.all.sdlmixer	Thu Jan  1 01:00:00 1970
+++ Chromium-0.9/scripts/Makefile.all.sdlmixer	Tue Oct  1 17:02:11 2002
@@ -0,0 +1,48 @@
+SUPPORT_DIRS	=	 \
+			./support/glpng/src
+
+CHROMIUM_DIRS	=	\
+			./src	\
+			./src-setup
+
+all: $(SUPPORT_DIRS) chromium
+
+chromium: $(CHROMIUM_DIRS) finish
+
+support: $(SUPPORT_DIRS)
+
+$(CHROMIUM_DIRS): FORCE
+	cd $@; $(MAKE)
+
+$(SUPPORT_DIRS): FORCE
+	cd $@; $(MAKE)
+
+finish: 
+	@echo ""
+	@mv -vf ./src/chromium ./bin
+	@mv -vf ./src-setup/chromium-setup ./bin
+	@echo ""
+	-ls --color ./bin/*
+	@echo ""
+	@echo "Now cd to ./bin and run chromium-setup!"
+	@echo ""
+
+clean:
+	for i in $(SUPPORT_DIRS); do ( cd $$i ; $(MAKE) clean ) ; done
+	for i in $(CHROMIUM_DIRS); do ( cd $$i ; $(MAKE) clean ) ; done
+	-rm -f ./bin/*
+	-rm -f *~ core
+	-rm -f *.bck
+
+distclean: clean
+	@echo ""
+	-rm -f scripts/*.bck
+	@echo -e "\n ** freshen up the doc files **\n--------------------------------"
+	-cp -f /home/mallan/HTML/mba/software/chromium/faq.htm ./data/doc
+	-cp -f /home/mallan/HTML/mba/software/chromium/info.htm ./data/doc
+	@echo ""
+	-rm -f ./config.mak
+	-rm -f ./Makefile
+	@echo ""
+
+FORCE:
diff -uNr Chromium-orig/scripts/Makefile.no-setup.sdlmixer Chromium-0.9/scripts/Makefile.no-setup.sdlmixer
--- Chromium-orig/scripts/Makefile.no-setup.sdlmixer	Thu Jan  1 01:00:00 1970
+++ Chromium-0.9/scripts/Makefile.no-setup.sdlmixer	Tue Oct  1 17:02:12 2002
@@ -0,0 +1,47 @@
+SUPPORT_DIRS	=	 \
+			./support/glpng/src
+
+CHROMIUM_DIRS	=	\
+			./src
+
+			
+all: $(SUPPORT_DIRS) chromium
+
+chromium: $(CHROMIUM_DIRS) finish
+
+support: $(SUPPORT_DIRS)
+
+$(CHROMIUM_DIRS): FORCE
+	cd $@; $(MAKE)
+
+$(SUPPORT_DIRS): FORCE
+	cd $@; $(MAKE)
+
+finish: 
+	@echo ""
+	@mv -vf ./src/chromium ./bin
+	@echo ""
+	-ls --color ./bin/*
+	@echo ""
+	@echo "Now cd to ./bin and run chromium!"
+	@echo ""
+
+clean:
+	for i in $(SUPPORT_DIRS); do ( cd $$i ; $(MAKE) clean ) ; done
+	for i in $(CHROMIUM_DIRS); do ( cd $$i ; $(MAKE) clean ) ; done
+	-rm -f ./bin/*
+	-rm -f *~ core
+	-rm -f *.bck
+
+distclean: clean
+	@echo ""
+	-rm -f scripts/*.bck
+	@echo -e "\n ** freshen up the doc files **\n--------------------------------"
+	-cp -f /home/mallan/HTML/mba/software/chromium/faq.htm ./data/doc
+	-cp -f /home/mallan/HTML/mba/software/chromium/info.htm ./data/doc
+	@echo ""
+	-rm -f ./config.mak
+	-rm -f ./Makefile
+	@echo ""
+
+FORCE:
diff -uNr Chromium-orig/scripts/configure_functions Chromium-0.9/scripts/configure_functions
--- Chromium-orig/scripts/configure_functions	Sat Mar 31 23:21:24 2001
+++ Chromium-0.9/scripts/configure_functions	Tue Oct  1 17:15:09 2002
@@ -48,6 +48,18 @@
 			--disable-setup )
 				ENABLE_SETUP="no"
 				;;
+			--enable-sdlmixer )
+				ENABLE_SDLMIXER="yes"
+				;;
+			--disable-sdlmixer )
+				ENABLE_SDLMIXER="no"
+				;;
+			--enable-openal )
+				ENABLE_OPENAL="yes"
+				;;
+			--disable-openal )
+				ENABLE_OPENAL="no"
+				;;
 			*)
 				print_command_line_options
 				exit 1
@@ -64,10 +76,12 @@
 	echo "--disable-<option>    disable option"
 	echo ""
 	echo "OPTIONS:"
-	echo "sdl     enable use of SDL libarary    (default: $ENABLE_SDL)"
-	echo "smpeg   enable SMPEG for MP3 playback (default: $ENABLE_SMPEG)"
-	echo "vorbis  enable Ogg/Vorbis support     (default: $ENABLE_VORBIS)"
-	echo "setup   build chromium-setup utility  (default: $ENABLE_SETUP)"
+	echo "sdl      enable use of SDL libarary    (default: $ENABLE_SDL)"
+	echo "smpeg    enable SMPEG for MP3 playback (default: $ENABLE_SMPEG)"
+	echo "vorbis   enable Ogg/Vorbis support     (default: $ENABLE_VORBIS)"
+	echo "setup    build chromium-setup utility  (default: $ENABLE_SETUP)"
+	echo "sdlmixer Use SDL_mixer for sound       (default: $ENABLE_SDLMIXER)"
+	echo "openal   Use openal for sound          (default: $ENABLE_OPENAL)"
 	echo ""
 	echo "EXAMPLE:"
 	echo "./configure --enable-smpeg --disable-vorbis"
diff -uNr Chromium-orig/src/AudioSDLMixer.h Chromium-0.9/src/AudioSDLMixer.h
--- Chromium-orig/src/AudioSDLMixer.h	Thu Feb  8 06:02:57 2001
+++ Chromium-0.9/src/AudioSDLMixer.h	Tue Oct  1 17:05:17 2002
@@ -10,6 +10,10 @@
 
 #ifdef AUDIO_SDLMIXER
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include <SDL_mixer.h>
 
 #include "Audio.h"
@@ -38,6 +42,9 @@
 	Mix_Chunk *sounds[NumSoundTypes];
 };
 
+#ifdef __cplusplus
+}
+#endif
 #endif // AUDIO_SDLMIXER
 
 #endif // AudioSDLMixer_h
diff -uNr Chromium-orig/src/Makefile Chromium-0.9/src/Makefile
--- Chromium-orig/src/Makefile	Tue May 22 07:25:50 2001
+++ Chromium-0.9/src/Makefile	Tue Oct  1 17:11:19 2002
@@ -10,8 +10,8 @@
 
 CC	=	gcc
 CXX	=	g++
-CFLAGS	=	-pipe $(PKG_CFLAGS) $(AL_CFLAGS) $(SDL_CFLAGS) $(SMPEG_CFLAGS) -O2 -DOLD_OPENAL -DAUDIO_OPENAL -D_REENTRANT
-CXXFLAGS=	-pipe $(PKG_CFLAGS) $(AL_CFLAGS) $(SDL_CFLAGS) $(SMPEG_CFLAGS) -O2 -DOLD_OPENAL -DAUDIO_OPENAL -D_REENTRANT
+CFLAGS	=	-pipe $(PKG_CFLAGS) $(AL_CFLAGS) $(SDL_CFLAGS) $(SMPEG_CFLAGS) -O2 $(OPENAL_FLAGS) $(SDLMIXER_FLAGS) -D_REENTRANT
+CXXFLAGS=	-pipe $(PKG_CFLAGS) $(AL_CFLAGS) $(SDL_CFLAGS) $(SMPEG_CFLAGS) -O2 $(OPENAL_FLAGS) $(SDLMIXER_FLAGS) -D_REENTRANT
 INCPATH	=	-I../support/include -I../support/glpng/include -I/usr/X11R6/include
 LINK	=	g++
 LFLAGS	=	

diff -uNr Chromium-orig/src/AudioSDLMixer.cpp Chromium-0.9/src/AudioSDLMixer.cpp
--- Chromium-orig/src/AudioSDLMixer.cpp	Mon May 21 03:15:15 2001
+++ Chromium-0.9/src/AudioSDLMixer.cpp	Tue Oct  1 17:04:35 2002
@@ -31,15 +31,15 @@
 	: Audio()
 {    
 	Config	*config = Config::instance();
-	//UNCLEAN - if initSound fails, config->getAudio() will be set to false
-	if(config->getAudio() == true)
+	//UNCLEAN - if initSound fails, config->audioEnabled() will be set to false
+	if(config->audioEnabled() == true)
 		initSound();
 }
 
 AudioSDLMixer::~AudioSDLMixer()
 {
 	Config	*config = Config::instance();
-	if(config->getAudio()) 
+	if(config->audioEnabled()) 
 	{
     	for (int i = 0; i < NumSoundTypes; i++)
         	Mix_FreeChunk (sounds[i]);
@@ -78,7 +78,7 @@
 void	AudioSDLMixer::playSound(SoundType type, float pos[3], int)
 {
 	Config	*config = Config::instance();
-	if (config->getAudio()) 
+	if (config->audioEnabled()) 
 	{
 		Mix_PlayChannel (-1, sounds[type], 0);
     }
@@ -91,7 +91,7 @@
 void AudioSDLMixer::pauseGameMusic(bool status)
 {
 	Config	*config = Config::instance();
-	if (config->getAudio()) 
+	if (config->audioEnabled()) 
 	{
 		if(cdrom)
 		{
@@ -114,7 +114,7 @@
 void	AudioSDLMixer::stopMusic()
 {
 	Config	*config = Config::instance();
-    if (config->getAudio()) 
+    if (config->audioEnabled()) 
 	{
 		Audio::stopMusic();
 		Mix_HaltChannel (0);
@@ -125,7 +125,7 @@
 void	AudioSDLMixer::setMusicMode(SoundType mode)
 {
 	Config	*config = Config::instance();
-    if (config->getAudio())
+    if (config->audioEnabled())
 	{
 		Audio::setMusicMode(mode);
 		switch(mode)
@@ -151,7 +151,7 @@
 void	AudioSDLMixer::setMusicVolume(float value)
 {
 	Config	*config = Config::instance();
-    if (config->getAudio())
+    if (config->audioEnabled())
 	{
 		Mix_Volume (0, (int)(MIX_MAX_VOLUME*value) );
 	}
@@ -164,7 +164,7 @@
 void	AudioSDLMixer::setSoundVolume(float value)
 {
 	Config	*config = Config::instance();
-    if (config->getAudio())
+    if (config->audioEnabled())
 	{
 		for (int i = 1; i < MIX_CHANNELS; i++)
 			Mix_Volume (i, (int)(MIX_MAX_VOLUME*value) );